@@ -1,14 +1,14 @@
-/* /usr/share/doc/libmpfi-doc/examples/mpfi_version.c */
+/* /usr/share/doc/libmpfi-doc/examples/mpfi_example_pi.c */
 
 /*
  * Ad hoc source sample for illustrating the use of the library mpfi
  *
  * Build and launch:
- *	$ gcc -o mpfi_version mpfi_version.c -lmpfi -lmpfr -lgmp -lm
- *	$ ./mpfi_version
+ *	$ gcc -o mpfi_example_pi mpfi_example_pi.c -lmpfi -lmpfr -lgmp -lm
+ *	$ ./mpfi_example_pi
  *
  * Written for Debian by Jerome Benoit <calculus@rezozer.net> on behalf of the Debian Science Team
- * Copyright: 2016 Jerome Benoit <calculus@rezozer.net>
+ * Copyright: 2016-2024 Jerome Benoit <calculus@rezozer.net>
  * Distributed under the terms and conditions of GPL version 2 or later
  */
 
